<?php

namespace Arch\Listeners;

use Illuminate\Database\Events\QueryExecuted;
use Monolog\Formatter\LineFormatter;
use Monolog\Handler\RotatingFileHandler;
use Monolog\Logger;

class QueryListener
{

    protected $logger;

    /**
     * Create the event listener.
     *
     * @return void
     */
    public function __construct()
    {
        $this->logger = new Logger(env('APP_NAME', 'APP_NAME'));
        $handler = new RotatingFileHandler(storage_path('/logs/sql.log'), 15);
        $formatter = new LineFormatter(null, null, false, true);
        $handler->setFormatter($formatter);
        $this->logger->pushHandler($handler);
    }

    /**
     * Handle the event.
     *
     * @param  QueryExecuted $event
     * @return void
     */
    public function handle(QueryExecuted $event)
    {
        if (env('APP_DEBUG')) {
            $sql = str_replace("?", "'%s'", $event->sql);
            $log = vsprintf($sql, $event->bindings);
            $requestId = app('request')->header('x-request-id','nginx_config_error');
            $text = "$requestId\t$log\t";
            $this->logger->debug($text, ['conn' => $event->connectionName, 'time' => $event->time.'ms']);
        }
    }

}
